# Tom's Statistics and Data Science Toolkit (tsdst)

![Upload Python Package](https://github.com/tomwerner5/tsdst/workflows/Upload%20Python%20Package/badge.svg)

## Introduction

This project began as a list of functions for tasks I did repeatedly and hated coding every new instance. Now, it has evolved into a statistical utility tool and a notepad. Some of these functions were created because I wanted to learn and understand the innards of some mathematical concept, and are thus not optimized in any way. Other functions have been used repeatedly on projects and are hopefully optimized to some extent.

Some of the more useful code here extends functionality of sklearn and other libraries.

Reach out if you have any feedback.

Documentation can be found [here:](https://tomwerner5.github.io/tsdst/Descriptions.html)

## Installation

To Install:

```{python}
pip install tsdst
```
